# Automations Best Practices
Examples and best practices for automations.
  * [Selected use cases](https://help.sap.com/docs/leanix/ea/automation-examples-selected-use-cases?locale=en-US&state=PRODUCTION&version=CLOUD "Explore automation examples for selected use cases."): Video tutorials for common scenarios.
  * [Use cases by triggers](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD "Explore automation examples for specific triggers."): Automation examples grouped by triggers:
    * Fact sheet created
    * Fact sheet field changed
    * Lifecycle phase changed
    * Quality state changed
    * Tag added or removed
    * Subscription added or removed
  * [Automations with webhooks](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Explore best practices and examples for setting up automations that send webhooks to a target URL."): Automations that send a webhook to a target URL.
  * [Automations with scripts](https://help.sap.com/docs/leanix/ea/examples-automations-with-scripts?locale=en-US&state=PRODUCTION&version=CLOUD "Explore use cases for automations with scripts."): Automations where actions involve running a script.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
